Config

Struct Config 

pub struct Config<I, const D: u8, BaseOrQuote>
where I: Mon<D>, BaseOrQuote: MarginCurrency<I, D>,
{ /* private fields */ }
Define the Exchange configuration.

Generics:

  • I: The numeric data type of currencies.
  • D: The constant decimal precision of the currencies.
  • BaseOrQuote: Either BaseCurrency or QuoteCurrency depending on the futures type.

Implementations

Source

impl<I, const D: u8, BaseOrQuote> Config<I, D, BaseOrQuote>
where I: Mon<D>, BaseOrQuote: MarginCurrency<I, D>,

pub fn contract_spec( &self, ) -> &ContractSpecification<I, D, BaseOrQuote::PairedCurrency>

The contract specification.

pub fn order_rate_limits(&self) -> &OrderRateLimits

The submission rate limits for orders.

Source

impl<I, const D: u8, BaseOrQuote> Config<I, D, BaseOrQuote>
where I: Mon<D>, BaseOrQuote: MarginCurrency<I, D>,

pub fn starting_wallet_balance(&self) -> BaseOrQuote

The starting balance of account (denoted in margin currency). The concrete Currency here defines the futures type. If QuoteCurrency is used as the margin currency, then its a linear futures contract. If BaseCurrency is used as the margin currency, then its an inverse futures contract.

pub fn max_num_open_orders(&self) -> NonZeroU16

The maximum number of open orders the user can have at any given time.

Source

impl<I, const D: u8, BaseOrQuote> Config<I, D, BaseOrQuote>
where I: Mon<D>, BaseOrQuote: MarginCurrency<I, D>,

pub fn new( starting_balance: BaseOrQuote, max_num_open_orders: NonZeroU16, contract_specification: ContractSpecification<I, D, BaseOrQuote::PairedCurrency>, order_rate_limits: OrderRateLimits, ) -> Result<Self, ConfigError>

Create a new Config.

Arguments:

starting_balance: Initial Wallet Balance, denoted in QUOTE if using linear futures, denoted in BASE for inverse futures max_num_open_orders: The maximum number of open ordes a user can have at any time. contract_specification: More details on the actual contract traded.

Returns:

Either a valid Config or an Error