pub struct Filled<I, const D: u8, BaseOrQuote>{ /* private fields */ }Expand description
The order has been fully filled. The executed order quantity is stored elsewhere.
Implementations
Sourceimpl<I, const D: u8, BaseOrQuote> Filled<I, D, BaseOrQuote>
impl<I, const D: u8, BaseOrQuote> Filled<I, D, BaseOrQuote>
Sourcepub fn meta(&self) -> &ExchangeOrderMeta
pub fn meta(&self) -> &ExchangeOrderMeta
The now filled in order metadata.
Sourceimpl<I, const D: u8, BaseOrQuote> Filled<I, D, BaseOrQuote>
impl<I, const D: u8, BaseOrQuote> Filled<I, D, BaseOrQuote>
Sourcepub fn ts_ns_executed(&self) -> TimestampNs
pub fn ts_ns_executed(&self) -> TimestampNs
The timestamp in nanoseconds when the order was executed by the exchange. Will be the simulated time, not actual computer (OS) time.
Sourcepub fn avg_fill_price(&self) -> QuoteCurrency<I, D>
pub fn avg_fill_price(&self) -> QuoteCurrency<I, D>
The average price the order has been filled at.
Sourcepub fn filled_qty(&self) -> BaseOrQuote
pub fn filled_qty(&self) -> BaseOrQuote
The total filled quantity.